/*
 * Copyright (c) 2021 Thomas Stranger
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr.h>
#include <sys/printk.h>
#include <drivers/eeprom.h>
#include <device.h>

#define WRITE_BUFFER 8
#define READ_BUFFER 256

#define EEPROM DT_NODELABEL(eeprom_0)

/*
 * Get a device structure from a devicetree node with alias eeprom
 */
static const struct device *get_eeprom_device(void)
{
	const struct device *dev = device_get_binding(DT_LABEL(EEPROM));

	if (!device_is_ready(dev)) {
		printk("\nError: Device \"%s\" is not ready; "
		       "check the driver initialization logs for errors.\n",
		       dev->name);
		return NULL;
	}

	printk("Found EEPROM device \"%s\"\n", dev->name);
	return dev;
}

void main(void){
	const struct device *eeprom = get_eeprom_device();
	if(eeprom == NULL){
		return;
	}

	uint8_t write_buffer[WRITE_BUFFER];
	for (int i = 0; i < WRITE_BUFFER; i++){
		write_buffer[i] = 120;
	}

	eeprom_write(eeprom, 0x10, write_buffer, sizeof(write_buffer));

	uint8_t read_buffer[READ_BUFFER];
	for (int i = 0; i < READ_BUFFER; i++){
		read_buffer[i] = 0;
	}

	int ok = eeprom_read(eeprom, 0x00, &read_buffer, sizeof(read_buffer));
	if(ok < 0){
		printk("Error reading from EEPROM; err: %d\n", ok);
		return;
	}
}
